Permission

Enum Permission 

pub enum Permission {
    Read,
    Write,
    GrantPermissions,
    Delete,
}
Available on crate feature documents only.
The possible permissions to grant to a specific application for a specific document.

Variants



Read

Read access.



Write

Write access.



GrantPermissions

The possibility to grant new permissions to the file.



Delete

Delete access.